package main

import (
	"flag"
	"fmt"

	"code.30cm.net/digimon/app-cloudep-wallet-service/gen_result/pb/wallet"
	"code.30cm.net/digimon/app-cloudep-wallet-service/internal/config"
	wallet_serviceServer "code.30cm.net/digimon/app-cloudep-wallet-service/internal/server/wallet_service"
	"code.30cm.net/digimon/app-cloudep-wallet-service/internal/svc"

	"github.com/zeromicro/go-zero/core/conf"
	"github.com/zeromicro/go-zero/core/service"
	"github.com/zeromicro/go-zero/zrpc"
	"google.golang.org/grpc"
	"google.golang.org/grpc/reflection"
)

var configFile = flag.String("f", "etc/wallet.yaml", "the config file")

func main() {
	flag.Parse()

	var c config.Config
	conf.MustLoad(*configFile, &c)
	ctx := svc.NewServiceContext(c)

	s := zrpc.MustNewServer(c.RpcServerConf, func(grpcServer *grpc.Server) {
		wallet.RegisterWallet_ServiceServer(grpcServer, wallet_serviceServer.NewWalletServiceServer(ctx))

		if c.Mode == service.DevMode || c.Mode == service.TestMode {
			reflection.Register(grpcServer)
		}
	})
	defer s.Stop()

	fmt.Printf("Starting rpc server at %s...\n", c.ListenOn)
	s.Start()
}
